Parses the show overview page and returns a tibble of show names with corresponding feed URLs, which in turn can then be passed to relay_parse_feed() individually.

relay_get_shows(cache = TRUE)

Arguments

cache

(logical(1)) Toggle the httr2 HTTP cache. Default TRUE.

Value

A tibble with one row for each show.

Examples

if (FALSE) { # \dontrun{
relay_get_shows()
} # }